﻿local ClassIconCoords = {
	["WARRIOR"] = {0, 0.25, 0, 0.25},
	["MAGE"] = {0.25, 0.49609375, 0, 0.25},
	["ROGUE"] = {0.49609375, 0.7421875, 0, 0.25},
	["DRUID"] = {0.7421875, 0.98828125, 0, 0.25},
	["HUNTER"] = {0, 0.25, 0.25, 0.5},
	["SHAMAN"] = {0.25, 0.49609375, 0.25, 0.5},
	["PRIEST"] = {0.49609375, 0.7421875, 0.25, 0.5},
	["WARLOCK"] = {0.7421875, 0.98828125, 0.25, 0.5},
	["PALADIN"] = {0, 0.25, 0.5, 0.75},
	["DEATHKNIGHT"] = {0.25, 0.49609375, 0.5, 0.75},
	["MONK"] = {0.50, 0.75, 0.50, 0.75 },
}

-- RaceCoords. For females, add 0.5 to "top" and "bottom".
-- http://i.imgur.com/VR5Xy.png -- Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Races
local RACE_COORD = {
	Human		= { left = 0/8, right = 1/8, top = 0/4, bottom = 1/4 },
	Dwarf		= { left = 1/8, right = 2/8, top = 0/4, bottom = 1/4 },
	Gnome		= { left = 2/8, right = 3/8, top = 0/4, bottom = 1/4 },
	NightElf	= { left = 3/8, right = 4/8, top = 0/4, bottom = 1/4 },
	Draenei		= { left = 4/8, right = 5/8, top = 0/4, bottom = 1/4 },
	Worgen		= { left = 5/8, right = 6/8, top = 0/4, bottom = 1/4 },

	Tauren		= { left = 0/8, right = 1/8, top = 1/4, bottom = 2/4 },
	Scourge		= { left = 1/8, right = 2/8, top = 1/4, bottom = 2/4 },
	Troll		= { left = 2/8, right = 3/8, top = 1/4, bottom = 2/4 },
	Orc			= { left = 3/8, right = 4/8, top = 1/4, bottom = 2/4 },
	BloodElf	= { left = 4/8, right = 5/8, top = 1/4, bottom = 2/4 },
	Goblin		= { left = 5/8, right = 6/8, top = 1/4, bottom = 2/4 },

	Pandaren	= { left = 6/8, right = 7/8, top = 0/4, bottom = 1/4 },	-- This uses the alliance images; the horde ones are just mirrored.
};

function Liquid_Wealth:BuildIcons(Toon,Scale)
  local texString_Race = ""
  local texString_Class = ""
  if Scale == nil then Scale = 15 end --If Scale was not passed though set a default
  local sex, race, class = strsplit(":", Toon);
  class = strupper(class);
  sex = tonumber(sex);
  
  local coords = RACE_COORD[race] or RACE_COORD.Human;
  local iconOffset = (sex == 3 and 0.5 or 0);
  
  texString_Race = "|TInterface\\Glues\\CharacterCreate\\UI-CharacterCreate-Races:" .. Scale ..":" .. Scale ..":0:0:512:256:" .. (coords.left + 0.01)*512 .. ":" .. (coords.right - 0.006)*512 .. ":".. (coords.top + iconOffset + 0.014)*256 ..":" .. (coords.bottom + iconOffset - 0.013)*256 .. "|t"
  texString_Class = "|TInterface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes:" .. Scale ..":" .. Scale ..":0:0:256:256:" .. ClassIconCoords[class][1]*256 .. ":" .. ClassIconCoords[class][2]*256 .. ":".. ClassIconCoords[class][3]*256 ..":" .. ClassIconCoords[class][4]*256 .."|t"
  return texString_Race .. texString_Class
end

function Liquid_Wealth:BuildBagIcons(itemID, ItemTexturePath, scale)
  if scale == nil then scale = 18 end
  if (itemID == "Bank") or (itemID == "Backpack") then --Show BagIcon for bank or backup
    return "|TInterface\\Icons\\INV_Misc_Bag_08:" .. scale .. "|t";
  elseif not (ItemTexturePath == nil) then
    return "|T" .. ItemTexturePath .. ":" .. scale .. "|t";
    --elseif (itemID=="NONE") or (itemID==nil) or (itemID=="") or (itemID==0) then
  else
    return "|TInterface\\GossipFrame\\ActiveQuestIcon:" .. scale .. "|t"; --Show QuestIcon if no bag is dected
  end
end

function Liquid_Wealth:ClassColor(Char)
  local fontcolor = "FFFFFF"
  local class
  if string.find(Char,":") then
     _, _, class = strsplit(":", Char)
  else
    class = Char
  end
  class = strupper(class)
  if (class == "DEATH KNIGHT") then
    fontcolor = "C41F3B"
  elseif (class == "DRUID") then
    fontcolor = "FF7D0A"
  elseif (class == "HUNTER") then
    fontcolor = "ABD473"
  elseif (class == "MAGE") then
    fontcolor = "69CCF0"
  elseif (class == "PALADIN") then
    fontcolor = "F58CBA"
  elseif (class == "PRIEST") then
    fontcolor = "FFFFFF"
  elseif (class == "ROGUE") then
    fontcolor = "FFF569"
  elseif (class == "SHAMAN") then
    fontcolor = "0070DE"
  elseif (class == "WARLOCK") then
    fontcolor = "9482C9"
  elseif (class == "WARRIOR") then
    fontcolor = "C79C6E"
  end
  return "FF" .. fontcolor
end
